# Sending Alerts to Slack and Microsoft Teams
### On this page
  * [Sending Alerts to Slack](https://help.sap.com/docs/leanix/ea/sending-alerts-to-slack-and-microsoft-teams#sending-alerts-to-slack)
  * [Sending Alerts to Microsoft Teams](https://help.sap.com/docs/leanix/ea/sending-alerts-to-slack-and-microsoft-teams#sending-alerts-to-microsoft-teams)


Set up a webhook to receive notifications about failed events in your integration runs.
To monitor the status of your integrations, you can set up a webhook to receive real-time notifications about events that fail during integration runs. This allows you to promptly address issues, minimizing downtime and ensuring the smooth operation of your integrations. To learn more about webhooks, see [Webhooks](https://help.sap.com/docs/leanix/ea/webhooks?locale=en-US&state=PRODUCTION&version=CLOUD "Listen to events in SAP LeanIX using webhooks.").
You can access synchronization logs for integrations in the Synchronization Logging section of the administration area. For more information, see [Synchronization Logging](https://help.sap.com/docs/leanix/ea/synchronization-logging?locale=en-US&state=PRODUCTION&version=CLOUD "Use synchronization logs to track the state of your integrations.").
